==> haskell-decimal-0.5.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-IpNyM6a5u6QI1sUj8Ap02X
key: Decimal-0.5.1-IpNyM6a5u6QI1sUj8Ap02X
license: BSD-3-Clause
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
abi: d3c59ed088d1ec21f39df69fbe0f451a
exposed: True
exposed-modules:
    Data.Decimal
import-dirs: /usr/lib/ghc-8.4.2/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-IpNyM6a5u6QI1sUj8Ap02X
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-CoPtTI9YM363muqQEsVUfq
key: Decimal-0.5.1-CoPtTI9YM363muqQEsVUfq
license: BSD-3-Clause
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
abi: 9c4315ba461f59a00d19f28143886add
exposed: True
exposed-modules:
    Data.Decimal
import-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-CoPtTI9YM363muqQEsVUfq
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
